@@ -4,6 +4,7 @@ import sys
 
 import click
 
+from toolkit.scaffold.project.ansible.cli import create_ansible_project
 from toolkit.scaffold.project.cpp.cli import create_cpp_project
 from toolkit.scaffold.project.docker.cli import create_docker_project
 from toolkit.scaffold.project.golang.cli import create_golang_project
@@ -16,6 +17,8 @@ def main():
     pass
 
 
+main.add_command(create_ansible_project, "ansible")
+
 main.add_command(create_cpp_project, "cpp")
 
 main.add_command(create_docker_project, "docker")
