@@ -4,6 +4,7 @@ import sys
 
 import click
 
+from toolkit.scaffold.project.golang.example import create_example
 from toolkit.scaffold.project.golang.web import create_web
 
 
@@ -12,6 +13,8 @@ def create_golang_project():
     pass
 
 
+create_golang_project.add_command(create_example, "example")
+
 create_golang_project.add_command(create_web, "web")
 
 if __name__ == "__main__":
