@@ -9,7 +9,7 @@ from toolkit.scaffold.project.template import TEMPLATE_PYTHON_PATH
 
 create_package = generate_create_project_command(
     command_help="Create a python package project scaffold.",
-    template_path=TEMPLATE_PYTHON_PATH / "package",
+    template_paths=TEMPLATE_PYTHON_PATH / "package",
     raw_user_input_context=USER_INPUT_CONTEXT | PYTHON_USER_INPUT_CONTEXT,
     user_input_context_hook=python_user_input_context_hook,
     project_context=PYTHON_CONTEXT,
